import Async from "typescene-async";
import Component from "./Component";
import TextLabelFactory from "./TextLabelFactory";
/** Component factory class: constructor creates and initializes a Component */
export interface ComponentFactory<T extends Component> {
    /** Contruct the component with all data contained in this factory */
    new (): T;
    /** Initializes more properties using given values; returns this */
    with(initializer: any): this;
    /** Initializes a property asynchronously using the value of an observable property from the base component (on which .with(...) or .initializeWith(...) was called), by property name/path, and using given transformation function, if any; useful for creating reusable component factories; returns this */
    withProperty(targetName: string, sourcePath: string, f?: (v: any) => any): this;
    /** Registers a callback to be invoked for every instance after initialization; callbacks are invoked with the created UI component as its first argument, and a base component (target for properties set from .id) as its second argument; returns this */
    then(callback: (component: T, factoryBase: Component) => void): this;
    /** Creates an instance (same as using constructor, but can be chained) */
    create(): T;
}
export declare type ValueOrObservable<T> = T | Async.ObservableValue<T>;
/** A factory initializer element (e.g. control element) */
export declare type ComponentFactorySpecElt = ValueOrObservable<ComponentFactory<Component> | TextLabelFactory | Component | typeof Component>;
/** A factory initializer element (e.g. control element) or table content */
export declare type ComponentFactorySpecEltTCol = ValueOrObservable<ComponentFactory<Component> | TextLabelFactory | Component | typeof Component | string | number>;
/** A list of factory initializer elements (e.g. row) */
export declare type ComponentFactorySpecList = ValueOrObservable<(ComponentFactorySpecElt | null)[]>;
/** A list of factory initializer elements (e.g. row) or table content */
export declare type ComponentFactorySpecListTCol = ValueOrObservable<(ComponentFactorySpecEltTCol | null)[]>;
/** A list of factory initializer elements, or a single element */
export declare type ComponentFactorySpecEltOrList = ValueOrObservable<ComponentFactorySpecElt | (ComponentFactorySpecElt | null)[]>;
/** A list of factory initializer elements, or a single element; or table content */
export declare type ComponentFactorySpecEltOrListTCol = ValueOrObservable<ComponentFactorySpecEltTCol | (ComponentFactorySpecEltTCol | null)[]>;
/** A list of (lists of) factory initializer elements */
export declare type ComponentFactorySpecList2 = ValueOrObservable<(ComponentFactorySpecEltOrList | null)[]>;
/** A list of (lists of) factory initializer elements or table content */
export declare type ComponentFactorySpecList2TCol = ValueOrObservable<(ComponentFactorySpecEltOrListTCol | null)[]>;
