import Async from "typescene-async";
import { ActionHandler, EventHandlerCtor } from "./DOMEvents";
import Component from "./Component";
/** Encapsulates output generated by a component's render method */
export declare abstract class ComponentRenderOutput<ElementT> {
    /** Create the output wrapper for given component and target element */
    constructor(component: Component, element: ElementT);
    /** The component that generated the output */
    component: Component;
    /** Reference to the actual output (e.g. DOM element) */
    element: ElementT;
    /** References to other (sub) elements, depending on component type; initially undefined but may contain multiple sub elements by name */
    elements: {
        [name: string]: ElementT;
    };
    /** Reference to element that should be used to register event handlers, if different from main element (otherwise undefined) */
    liveElement: ElementT;
    /** Flag that can be used for duck typing */
    isComponentOutput: boolean;
}
/** Encapsulates HTML output generated by a component's render method */
export declare class ComponentRenderHtmlOutput extends ComponentRenderOutput<HTMLElement> {
}
/** Event data that is emitted when a component updates its DOM output */
export interface ComponentRenderEvent {
    /** The component that has been rendered */
    component: Component;
    /** The output generated by the component */
    out: ComponentRenderOutput<any>;
}
/** Signal that is emitted when a component updates its rendered output */
export interface ComponentRenderSignal extends Async.CustomSignalClass<ComponentRenderEvent, Async.Signal<ComponentRenderEvent>> {
}
export interface RenderHandler extends ActionHandler<ComponentRenderEvent, ComponentRenderSignal> {
}
/** Constructor for a component render event handler */
export declare var RenderHandler: EventHandlerCtor<ComponentRenderEvent, RenderHandler>;
export default ComponentRenderOutput;
