import Container from "./Container";
import { Block } from "../";
import { ComponentFactory, ValueOrObservable, ComponentFactorySpecList2 } from "../ComponentFactory";
/** Represents a modal container displayed on the side of the screen */
export declare class DrawerContainer extends Container {
    /** Create a drawer component with given content, if any */
    constructor(content?: Block[], width?: string, maxOuterWidth?: string, openFromRight?: boolean);
    /** Initialize a drawer factory with given values */
    static with: (values: DrawerContainer.Initializer) => ComponentFactory<DrawerContainer>;
    /** Initialize a drawer factory with given content */
    static withContent: (content: ComponentFactorySpecList2) => ComponentFactory<DrawerContainer>;
    /** Initialize with given (observable) values; returns this */
    initializeWith: (values: DrawerContainer.Initializer) => this;
    /** Default width (CSS value, observed), defaults to 20rem; limited by maxOuterWidth which itself defaults to 90% */
    width: string;
    /** Max width of drawer itself, defaults to 90% (observed) */
    maxOuterWidth: string;
    /** True if drawer should open from the right (default false, observed) */
    openFromRight: boolean;
    /** Remove drawer from screen; returns this */
    close(): this;
    /** Display this drawer on screen; returns this */
    display(): this;
}
export declare namespace DrawerContainer {
    /** Initializer for .with({ ... }) */
    interface Initializer extends Container.Initializer {
        /** Property initializer */
        width?: ValueOrObservable<string>;
        /** Property initializer */
        openFromRight?: ValueOrObservable<boolean>;
    }
}
export default DrawerContainer;
